# This file was auto-generated by Fern from our API Definition.

import typing
from .system_message_input import SystemMessageInput
from .user_message_input import UserMessageInput
from .assistant_message_input import AssistantMessageInput
from .tool_message import ToolMessage

ChatCompletionRequestMessagesItem = typing.Union[
    SystemMessageInput, UserMessageInput, AssistantMessageInput, ToolMessage
]
