# This file was auto-generated by Fern from our API Definition.

import typing
from .tool_function_choice import ToolFunctionChoice

ChatCompletionRequestToolChoice = typing.Union[
    typing.Literal["none"], typing.Literal["auto"], typing.Literal["required"], ToolFunctionChoice
]
