# This file was auto-generated by Fern from our API Definition.

import typing

AppAuthSchemeAuthMode = typing.Union[
    typing.Literal["OAUTH2", "OAUTH1", "API_KEY", "BASIC", "BEARER_TOKEN", "BASIC_WITH_JWT"], typing.Any
]
