# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
from .choice import Choice
import datetime as dt
from .usage_statistics import UsageStatistics
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class ChatCompletionResponse(UncheckedBaseModel):
    """
    https://platform.openai.com/docs/api-reference/chat/object
    """

    id: str
    choices: typing.List[Choice]
    created: dt.datetime
    model: typing.Optional[str] = None
    system_fingerprint: typing.Optional[str] = None
    object: typing.Optional[typing.Literal["chat.completion"]] = None
    usage: UsageStatistics

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
